YARP 2.3.6 (2011-07-11)                                                {#v2_3_6}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.5...v2.3.6`):

```
    16	Paul Fitzpatrick <paulfitz@alum.mit.edu>
     9	Ugo Pattacini <ugo.pattacini@iit.it>
     3	Lorenzo Natale <lorenzo.natale@iit.it>
     1	Alessandro Scalzo <alessandro.scalzo@iit.it>
```
